# rlgym-tools
Extra tools for RLGym.

Contains environment alternatives for [Stable-Baselines3](https://stable-baselines3.readthedocs.io/en/master/), [RLlib](https://docs.ray.io/en/master/rllib.html) and [PettingZoo](https://www.pettingzoo.ml/), replay to RLGym GameState converter, and advanced reward functions. 

Check out the [RLGym wiki](https://rlgym.github.io/) for more info: 

## Installation
`pip install rlgym-tools`
